@@ -3,7 +3,7 @@ col2hex <- function(cname)
     colMat <- col2rgb(cname)
     rgb(
         red=colMat[1,]/255,
-        blue=colMat[2,]/255,
-        green=colMat[3,]/255
+        green=colMat[2,]/255,
+        blue=colMat[3,]/255
         )
   }
